<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns="http://www.w3.org/1999/xhtml"
	xmlns:date="http://exslt.org/dates-and-times"
    extension-element-prefixes="date">
	<xsl:output method="text" indent="no" encoding="UTF-8" />

	<xsl:template match="/PAP">
const BigDecimal = require('bigdecimal').BigDecimal,
  PAPBaseClass = require('../PAPBaseClass');


		<xsl:apply-templates select="./CONSTANTS" />
class <xsl:value-of select="./@name" /> extends PAPBaseClass {
	constructor() {
		super();
		this.name = '<xsl:value-of select="./@name" />';
		this.inputs = {};
		this.outputs = {};
		this.internals = {};
		<xsl:apply-templates select="./VARIABLES" />
	}
	<xsl:apply-templates select="./METHODS" />
}

<xsl:for-each select="./CONSTANTS/CONSTANT">
	<xsl:value-of select="/PAP/@name" />.<xsl:value-of select="./@name" /> = <xsl:value-of select="./@name" />;
</xsl:for-each>

module.exports = <xsl:value-of select="./@name" />;
	</xsl:template>


	<xsl:template match="INPUT"><xsl:call-template name="variablesInput" /></xsl:template>
	<xsl:template match="OUTPUT"><xsl:call-template name="variablesOutput" /></xsl:template>
	<xsl:template match="INTERNAL"><xsl:call-template name="variablesInternal" /></xsl:template>
	<xsl:template match="CONSTANT"><xsl:call-template name="constant" /></xsl:template>
	<xsl:template match="MAIN">main() {<xsl:apply-templates select="child::node()" />}</xsl:template>
	<xsl:template match="METHOD"><xsl:value-of select="./@name" />() {<xsl:apply-templates select="child::node()" />}</xsl:template><xsl:template match="EXECUTE"><xsl:value-of select="./@method" />();</xsl:template>
	<xsl:template match="EVAL"><xsl:value-of select="./@exec" />;</xsl:template>
	<xsl:template match="IF">if (<xsl:value-of select="./@expr" />) {<xsl:apply-templates select="child::node()" />}</xsl:template>
	<xsl:template match="THEN"><xsl:apply-templates select="child::node()" /></xsl:template>
	<!-- Standard case: <IF><THEN>...</THEN><ELSE>...</ELSE></IF> -->
	<xsl:template match="ELSE[parent::IF]">}else {<xsl:apply-templates select="child::node()" /></xsl:template>
	<!-- Bug case: <IF><THEN>...</THEN></IF><ELSE>...</ELSE> -->
	<xsl:template match="ELSE[not(parent::IF)]">else {<xsl:apply-templates select="child::node()" />}</xsl:template>
	<xsl:template match="comment()">/** <xsl:value-of select="."/> */</xsl:template>



	<xsl:template name="variablesInput">this.inputs.<xsl:value-of select="./@name" /> = <xsl:choose><xsl:when test="@default and string-length(@default)>0"><xsl:value-of select="./@default" /></xsl:when><xsl:when test="@type='BigDecimal'">new BigDecimal(0)</xsl:when><xsl:otherwise>0</xsl:otherwise></xsl:choose>;</xsl:template>
	<xsl:template name="variablesOutput">this.outputs.<xsl:value-of select="./@name" /> = <xsl:choose><xsl:when test="@default and string-length(@default)>0"><xsl:value-of select="./@default" /></xsl:when><xsl:when test="@type='BigDecimal'">new BigDecimal(0)</xsl:when><xsl:otherwise>0</xsl:otherwise></xsl:choose>;</xsl:template>
	<xsl:template name="variablesInternal">this.internals.<xsl:value-of select="./@name" /> = <xsl:choose><xsl:when test="@default and string-length(@default)>0"><xsl:value-of select="./@default" /></xsl:when><xsl:when test="@type='BigDecimal'">new BigDecimal(0)</xsl:when><xsl:otherwise>0</xsl:otherwise></xsl:choose>;</xsl:template>

	<xsl:template name="constant">const <xsl:value-of select="./@name" /> = <xsl:value-of select="translate(./@value,'{}','[]')" />;</xsl:template>


</xsl:stylesheet>
