const child_process = require( 'child_process' ),
  path              = require( 'path' ),
  fs                = require( 'fs' );

const regexTabs            = /\t/g,
  regexVariables           = /this\.(.+?)\.(.+?) = /g,
  regexMethods             = /^ *(.+?)\(\) \{/gm,
  regexBigDecimalConstants = /BigDecimal\.(ZERO|ONE|TEN)/g,
  regexCleanDuplicated     = /(this\.(inputs|outputs|internals)\.)this\.(inputs|outputs|internals)\./g,
  regexSuffixes            = /(\W)([0-9.]+)[LD](\W)/g;

const dirPaps    = __dirname + '/../paps/',
  dirCalculators = __dirname + '/../lib/calculators/';


let filenames = fs.readdirSync( dirPaps );


for (let filename of filenames) {

  xslt( filename );

  postProcess( filename );
}


function xslt( filename ) {
  let basename = path.basename( filename, '.xml' );
  child_process.execSync( `xsltproc -o ${dirCalculators + basename}.js ${__dirname}/generate.xsl ${dirPaps + filename}` );
}


function postProcess( filename ) {

  let basename = path.basename( filename, '.xml' ),
    file       = fs.readFileSync( dirCalculators + basename + '.js', 'utf8' ),
    matches    = [],
    match;

  regexVariables.lastIndex       = 0;
  regexMethods.lastIndex         = 0;
  regexCleanDuplicated.lastIndex = 0;

  file = file.replace( regexTabs, '  ' );

  while (match = regexVariables.exec( file )) {
    matches.push( match );
  }

  for (match of matches) {
    file = file.replace( new RegExp( '(\\W)' + match[ 2 ] + '(\\W)', 'g' ), '$1' + match[ 0 ].slice( 0, -3 ) + '$2' );
  }

  matches = [];

  while (match = regexMethods.exec( file )) {
    matches.push( match );
  }

  for (match of matches) {
    file = file.replace( new RegExp( '(\\W)' + match[ 1 ] + '\\(\\);', 'g' ), '$1this.' + match[ 1 ] + '();' );
  }

  file = file
    .replace( regexCleanDuplicated, '$1' )
    .replace( regexBigDecimalConstants, 'BigDecimal.$1()' )
    .replace( regexSuffixes, '$1$2$3' );

  fs.writeFileSync( dirCalculators + basename + '.js', file );
}
