
const BigDecimal = require('bigdecimal').BigDecimal,
  PAPBaseClass = require('../PAPBaseClass');


    
        /**  Tabelle fuer die Vomhundertsaetze des Versorgungsfreibetrags  */
        const TAB1 = [0.0, 0.400, 0.384, 0.368, 0.352, 0.336, 0.320, 0.304, 0.288, 0.272, 0.256, 0.240, 0.224, 0.208, 0.192, 0.176, 0.160, 0.152, 0.144, 0.136, 0.128, 0.120, 0.112, 0.104, 0.096, 0.088, 0.080, 0.072, 0.064, 0.056, 0.048, 0.040, 0.032, 0.024, 0.016, 0.008, 0.000];

        /**  Tabelle fuer die Hoechstbetrage des Versorgungsfreibetrags  */
        const TAB2 = [0, 3000, 2880, 2760, 2640, 2520, 2400, 2280, 2160, 2040, 1920, 1800, 1680, 1560, 1440, 1320, 1200, 1140, 1080, 1020, 960, 900, 840, 780, 720, 660, 600, 540, 480, 420, 360, 300, 240, 180, 120, 60, 0];

        /**  Tabelle fuer die Zuschlaege zum Versorgungsfreibetrag  */
        const TAB3 = [0, 900, 864, 828, 792, 756, 720, 684, 648, 612, 576, 540, 504, 468, 432, 396, 360, 342, 324, 306, 288, 270, 252, 234, 216, 198, 180, 162, 144, 126, 108, 90, 72, 54, 36, 18, 0];

        /**  Tabelle fuer die Vomhundertsaetze des Altersentlastungsbetrags  */
        const TAB4 = [0.0, 0.400, 0.384, 0.368, 0.352, 0.336, 0.320, 0.304, 0.288, 0.272, 0.256, 0.240, 0.224, 0.208, 0.192, 0.176, 0.160, 0.152, 0.144, 0.136, 0.128, 0.120, 0.112, 0.104, 0.096, 0.088, 0.080, 0.072, 0.064, 0.056, 0.048, 0.040, 0.032, 0.024, 0.016, 0.008, 0.000];

        /**  Tabelle fuer die Hoechstbetraege des Altersentlastungsbetrags  */
        const TAB5 = [0, 1900, 1824, 1748, 1672, 1596, 1520, 1444, 1368, 1292, 1216, 1140, 1064, 988, 912, 836, 760, 722, 684, 646, 608, 570, 532, 494, 456, 418, 380, 342, 304, 266, 228, 190, 152, 114, 76, 38, 0];

        /**  Zahlenkonstanten fuer im Plan oft genutzte BigDecimal Werte  */
        const ZAHL0 = new BigDecimal(0);
        const ZAHL1 = new BigDecimal(1);
        const ZAHL2 = new BigDecimal(2);
        const ZAHL3 = new BigDecimal(3);
        const ZAHL4 = new BigDecimal(4);
        const ZAHL5 = new BigDecimal(5);
        const ZAHL6 = new BigDecimal(6);
        const ZAHL7 = new BigDecimal(7);
        const ZAHL8 = new BigDecimal(8);
        const ZAHL9 = new BigDecimal(9);
        const ZAHL10 = new BigDecimal(10);
        const ZAHL11 = new BigDecimal(11);
        const ZAHL12 = new BigDecimal(12);

        const ZAHL100 = new BigDecimal(100);
        const ZAHL360 = new BigDecimal(360);

    
class Lohnsteuer2006Big extends PAPBaseClass {
  constructor() {
    super();
    this.name = 'Lohnsteuer2006Big';
    this.inputs = {};
    this.outputs = {};
    this.internals = {};
    

    /**   EINGABEPARAMETER   */
 
        /**  Auf die Vollendung des 64. Lebensjahres folgende 
             Kalenderjahr (erforderlich, wenn this.inputs.ALTER1=1)  */
        this.inputs.AJAHR = 0;
                
        /**  1, wenn das 64. Lebensjahr zu Beginn des Kalenderjahres vollendet wurde, in dem 
             der Lohnzahlungszeitraum endet (§ 24 a EStG), sonst = 0  */
        this.inputs.ALTER1 = 0;

        /**  In der Lohnsteuerkarte des Arbeitnehmers eingetragener Hinzurechnungsbetrag
             fuer den Lohnzahlungszeitraum in Cents  */
        this.inputs.HINZUR = new BigDecimal(0);

        /**  Jahresfreibetrag nach Ma&szlig;gabe der Eintragungen auf der
             Lohnsteuerkarte in Cents (ggf. 0)  */
        this.inputs.JFREIB = new BigDecimal(0);

        /**  Jahreshinzurechnungsbetrag in Cents (ggf. 0)  */
        this.inputs.JHINZU = new BigDecimal(0);

        /**  Voraussichtlicher Jahresarbeitslohn ohne sonstige Bezuege und
             ohne Verguetung fuer mehrjaehrige Taetigkeit in Cents (ggf. 0)
             Anmerkung: Die Eingabe dieses Feldes ist erforderlich bei Eingabe
             „sonstiger Bezuege“ (Feld this.inputs.SONSTB) oder bei Eingabe der „Verguetung
             fuer mehrjaehrige Taetigkeit“ (Feld this.inputs.VMT).  */
        this.inputs.JRE4 = new BigDecimal(0);

        /**  In this.inputs.JRE4 enthaltene Versorgungsbezuege in Cents (ggf. 0)  */
        this.inputs.JVBEZ = new BigDecimal(0);

        /**  1 = der Arbeitnehmer ist im Lohnzahlungszeitraum in der gesetzlichen
             Rentenversicherung versicherungsfrei und gehoert zu den in
             § 10 c Abs. 3 EStG genannten Personen.
             Bei anderen Arbeitnehmern ist „0“ einzusetzen.
             Fuer die Zuordnung sind allein die dem Arbeitgeber ohnehin bekannten
             Tatsachen ma&szlig;gebend; zusaetzliche Ermittlungen braucht
             der Arbeitgeber nicht anzustellen.  */
        this.inputs.KRV = 0;

        /**  Lohnzahlungszeitraum:
             1 = Jahr
             2 = Monat
             3 = Woche
             4 = Tag  */
        this.inputs.LZZ = 0;

        /**  Religionsgemeinschaft des Arbeitnehmers lt. Lohnsteuerkarte (bei
             keiner Religionszugehoerigkeit = 0)  */
        this.inputs.R = 0;

        /**  Steuerpflichtiger Arbeitslohn vor Beruecksichtigung der Freibetraege
             fuer Versorgungsbezuege, des Altersentlastungsbetrags und des auf
             der Lohnsteuerkarte fuer den Lohnzahlungszeitraum eingetragenen
             Freibetrags in Cents.  */
        this.inputs.RE4 = new BigDecimal(0);

        /**  Sonstige Bezuege (ohne Verguetung aus mehrjaehriger Taetigkeit) einschliesslich 
             Sterbegeld bei Versorgungsbezuegen sowie Kapitalauszahlungen/Abfindungen, 
             soweit es sich nicht um Bezuege fuer mehrere Jahre handelt in Cents (ggf. 0)  */
        this.inputs.SONSTB = new BigDecimal(0);

        /**  Sterbegeld bei Versorgungsbezuegen sowie Kapitalauszahlungen/Abfindungen, 
             soweit es sich nicht um Bezuege fuer mehrere Jahre handelt 
             (in this.inputs.SONSTB enthalten) in Cents  */
        this.inputs.STERBE = new BigDecimal(0);

        /**  Steuerklasse:
             1 = I
             2 = II
             3 = III
             4 = IV
             5 = V
             6 = VI  */
        this.inputs.STKL = 0;

        /**  In this.inputs.RE4 enthaltene Versorgungsbezuege in Cents (ggf. 0)  */
        this.inputs.VBEZ = new BigDecimal(0);

        /**  Vorsorgungsbezug im Januar 2005 bzw. fuer den ersten vollen Monat
             in Cents */
        this.inputs.VBEZM = new BigDecimal(0);

        /**  Voraussichtliche Sonderzahlungen im Kalenderjahr des Versorgungsbeginns 
             bei Versorgungsempfaengern ohne Sterbegeld, Kapitalauszahlungen/Abfindungen 
             bei Versorgungsbezuegen in Cents */
        this.inputs.VBEZS = new BigDecimal(0);

        /**  In this.inputs.SONSTB enthaltene Versorgungsbezuege einschliesslich Sterbegeld 
            in Cents (ggf. 0)  */
        this.inputs.VBS = new BigDecimal(0);

        /**  Jahr, in dem der Versorgungsbezug erstmalig gewaehrt wurde; werden 
             mehrere Versorgungsbezuege gezahlt, so gilt der aelteste erstmalige Bezug  */
        this.inputs.VJAHR = 0;

        /**  Kapitalauszahlungen/Abfindungen bei Versorgungsbezuegen fuer mehrere Jahre in Cents (ggf. 0)  */
        this.inputs.VKAPA = new BigDecimal(0);

        /**  Verguetung fuer mehrjaehrige Taetigkeit ohne Kapitalauszahlungen/Abfindungen bei 
             Versorgungsbezuegen in Cents (ggf. 0)  */
        this.inputs.VMT = new BigDecimal(0);

        /**  In der Lohnsteuerkarte des Arbeitnehmers eingetragener Freibetrag
             fuer den Lohnzahlungszeitraum in Cents  */
        this.inputs.WFUNDF = new BigDecimal(0);

        /**  Zahl der Freibetraege fuer Kinder (eine Dezimalstelle, nur bei Steuerklassen
             I, II, III und IV)  */
        this.inputs.ZKF = new BigDecimal(0);

        /**  Zahl der Monate, fuer die Versorgungsbezuege gezahlt werden (nur
             erforderlich bei Jahresberechnung (this.inputs.LZZ = 1)  */
        this.inputs.ZMVB = 0;

      

      /**   AUSGABEPARAMETER   */
    

        /**  Bemessungsgrundlage fuer die Kirchenlohnsteuer in Cents  */
        this.outputs.BK = new BigDecimal(0);

        /**  Bemessungsgrundlage der sonstigen Einkuenfte (ohne Verguetung
             fuer mehrjaehrige Taetigkeit) fuer die Kirchenlohnsteuer in Cents  */
        this.outputs.BKS = new BigDecimal(0);

        this.outputs.BKV = new BigDecimal(0);

        /**  Fuer den Lohnzahlungszeitraum einzubehaltende Lohnsteuer in Cents  */
        this.outputs.LSTLZZ = new BigDecimal(0);

        /**  Fuer den Lohnzahlungszeitraum einzubehaltender Solidaritaetszuschlag
             in Cents  */
        this.outputs.SOLZLZZ = new BigDecimal(0);

        /**  Solidaritaetszuschlag fuer sonstige Bezuege (ohne Verguetung fuer mehrjaehrige
             Taetigkeit) in Cents  */
        this.outputs.SOLZS = new BigDecimal(0);

        /**  Solidaritaetszuschlag fuer die Verguetung fuer mehrjaehrige Taetigkeit in
             Cents  */
        this.outputs.SOLZV = new BigDecimal(0);

        /**  Lohnsteuer fuer sonstige Einkuenfte (ohne Verguetung fuer mehrjaehrige
             Taetigkeit) in Cents  */
        this.outputs.STS = new BigDecimal(0);

        /**  Lohnsteuer fuer Verguetung fuer mehrjaehrige Taetigkeit in Cents  */
        this.outputs.STV = new BigDecimal(0);


       

      /**   INTERNE FELDER   */
    

        /**  Altersentlastungsbetrag nach Alterseinkuenftegesetz in Cents  */
        this.internals.ALTE = new BigDecimal(0);

        /**  Arbeitnehmer-Pauschbetrag in EURO  */
        this.internals.ANP = new BigDecimal(0);

        /**  Auf den Lohnzahlungszeitraum entfallender Anteil von Jahreswerten
             auf ganze Cents abgerundet  */
        this.internals.ANTEIL1 = new BigDecimal(0);

        /**  Auf den Lohnzahlungszeitraum entfallender Anteil von Jahreswerten
             auf ganze Cents aufgerundet  */
        this.internals.ANTEIL2 = new BigDecimal(0);

        /**  Bemessungsgrundlage fuer Altersentlastungsbetrag in Cents  */
        this.internals.BMG = new BigDecimal(0);

        /**  Differenz zwischen this.internals.ST1 und this.internals.ST2 in EURO  */
        this.internals.DIFF = new BigDecimal(0);

        /**  Entlastungsbetrag fuer Alleinerziehende in EURO  */
        this.internals.EFA = new BigDecimal(0);

        /**  Versorgungsfreibetrag in Cents  */
        this.internals.FVB = new BigDecimal(0);

        /**  Zuschlag zum Versorgungsfreibetrag in EURO  */
        this.internals.FVBZ = new BigDecimal(0);

        /**  Massgeblich maximaler Versorgungsfreibetrag in Cents  */
        this.internals.HFVB = new BigDecimal(0);

        /**  Nummer der Tabellenwerte fuer Versorgungsparameter  */
        this.internals.J = 0;

        /**  Jahressteuer nach § 51a EStG, aus der Solidaritaetszuschlag und
             Bemessungsgrundlage fuer die Kirchenlohnsteuer ermittelt werden in EURO  */
        this.internals.JBMG = new BigDecimal(0);

        /**  Jahreswert, dessen Anteil fuer einen Lohnzahlungszeitraum in
             UPANTEIL errechnet werden soll in Cents  */
        this.internals.JW = new BigDecimal(0);

        /**  Nummer der Tabellenwerte fuer Parameter bei Altersentlastungsbetrag  */
        this.internals.K = 0;

        /**  Kennzeichen bei Verguetung fuer mehrjaehrige Taetigkeit
             0 = beim Vorwegabzug ist this.internals.ZRE4VP zu beruecksichtigen
             1 = beim Vorwegabzug ist this.internals.ZRE4VP1 zu beruecksichtigen  */
        this.internals.KENNZ = 0;

        /**  Summe der Freibetraege fuer Kinder in EURO  */
        this.internals.KFB = new BigDecimal(0);

        /**  Kennzahl fuer die Einkommensteuer-Tabellenart:
             1 = Grundtabelle
             2 = Splittingtabelle  */
        this.internals.KZTAB = 0;

        /**  Jahreslohnsteuer in EURO  */
        this.internals.LSTJAHR = new BigDecimal(0);

        /**  Zwischenfelder der Jahreslohnsteuer in Cents  */
        this.internals.LST1 = new BigDecimal(0);
        this.internals.LST2 = new BigDecimal(0);
        this.internals.LST3 = new BigDecimal(0);

        /**  Mindeststeuer fuer die Steuerklassen V und VI in EURO  */
        this.internals.MIST = new BigDecimal(0);

        /**  Arbeitslohn des Lohnzahlungszeitraums nach Abzug der Freibetraege
             fuer Versorgungsbezuege, des Altersentlastungsbetrags und des
             in der Lohnsteuerkarte eingetragenen Freibetrags und Hinzurechnung
             eines Hinzurechnungsbetrags in Cents. Entspricht dem Arbeitslohn,
             fuer den die Lohnsteuer im personellen Verfahren aus der
             zum Lohnzahlungszeitraum gehoerenden Tabelle abgelesen wuerde  */
        this.internals.RE4LZZ = new BigDecimal(0);

        /**  Arbeitslohn des Lohnzahlungszeitraums nach Abzug der Freibetraege
             fuer Versorgungsbezuege und des Altersentlastungsbetrags in
             Cents zur Berechnung der Vorsorgepauschale  */
        this.internals.RE4LZZV = new BigDecimal(0);

        /**  Rechenwert in Gleitkommadarstellung  */
        this.internals.RW = new BigDecimal(0);

        /**  Sonderausgaben-Pauschbetrag in EURO  */
        this.internals.SAP = new BigDecimal(0);

        /**  Freigrenze fuer den Solidaritaetszuschlag in EURO  */
        this.internals.SOLZFREI = new BigDecimal(0);

        /**  Solidaritaetszuschlag auf die Jahreslohnsteuer in EURO, C (2 Dezimalstellen)  */
        this.internals.SOLZJ = new BigDecimal(0);

        /**  Zwischenwert fuer den Solidaritaetszuschlag auf die Jahreslohnsteuer
             in EURO, C (2 Dezimalstellen)  */
        this.internals.SOLZMIN = new BigDecimal(0);

        /**  Tarifliche Einkommensteuer in EURO  */
        this.internals.ST = new BigDecimal(0);

        /**  Tarifliche Einkommensteuer auf das 1,25-fache this.internals.ZX in EURO  */
        this.internals.ST1 = new BigDecimal(0);

        /**  Tarifliche Einkommensteuer auf das 0,75-fache this.internals.ZX in EURO  */
        this.internals.ST2 = new BigDecimal(0);

        /**  Bemessungsgrundlage fuer den Versorgungsfreibetrag in Cents  */
        this.internals.VBEZB = new BigDecimal(0);

        /**  Hoechstbetrag der Vorsorgepauschale nach Alterseinkuenftegesetz in EURO, C  */
        this.internals.VHB = new BigDecimal(0);

        /**  Vorsorgepauschale in EURO, C (2 Dezimalstellen)  */
        this.internals.VSP = new BigDecimal(0);

        /**  Vorsorgepauschale nach Alterseinkuenftegesetz in EURO, C  */
        this.internals.VSPN = new BigDecimal(0);

        /**  Zwischenwert 1 bei der Berechnung der Vorsorgepauschale nach
             dem Alterseinkuenftegesetz in EURO, C (2 Dezimalstellen)  */
        this.internals.VSP1 = new BigDecimal(0);

        /**  Zwischenwert 2 bei der Berechnung der Vorsorgepauschale nach
             dem Alterseinkuenftegesetz in EURO, C (2 Dezimalstellen)  */
        this.internals.VSP2 = new BigDecimal(0);

        /**  Hoechstbetrag der Vorsorgepauschale nach § 10c Abs. 3 EStG in EURO  */
        this.internals.VSPKURZ = new BigDecimal(0);

        /**  Hoechstbetrag der Vorsorgepauschale nach § 10c Abs. 2 Nr. 2 EStG in EURO  */
        this.internals.VSPMAX1 = new BigDecimal(0);

        /**  Hoechstbetrag der Vorsorgepauschale nach § 10c Abs. 2 Nr. 3 EStG in EURO  */
        this.internals.VSPMAX2 = new BigDecimal(0);

        /**  Vorsorgepauschale nach § 10c Abs. 2 Satz 2 EStG vor der Hoechstbetragsberechnung
             in EURO, C (2 Dezimalstellen)  */
        this.internals.VSPO = new BigDecimal(0);

        /**  Fuer den Abzug nach § 10c Abs. 2 Nrn. 2 und 3 EStG verbleibender
             Rest von this.internals.VSPO in EURO, C (2 Dezimalstellen)  */
        this.internals.VSPREST = new BigDecimal(0);

        /**  Hoechstbetrag der Vorsorgepauschale nach § 10c Abs. 2 Nr. 1 EStG
             in EURO, C (2 Dezimalstellen)  */
        this.internals.VSPVOR = new BigDecimal(0);

        /**  Zu versteuerndes Einkommen gem. § 32a Abs. 1 und 2 EStG
             (2 Dezimalstellen)  */
        this.internals.X = new BigDecimal(0);

        /**  gem. § 32a Abs. 1 EStG (6 Dezimalstellen)  */
        this.internals.Y = new BigDecimal(0);

        /**  Auf einen Jahreslohn hochgerechnetes this.internals.RE4LZZ in EURO, C (2 Dezimalstellen)  */
        this.internals.ZRE4 = new BigDecimal(0);

        /**  Auf einen Jahreslohn hochgerechnetes this.internals.RE4LZZV zur Berechnung
             der Vorsorgepauschale in EURO, C (2 Dezimalstellen)  */
        this.internals.ZRE4VP = new BigDecimal(0);

        /**  Sicherungsfeld von this.internals.ZRE4VP in EURO,C bei der Berechnung des Vorwegabzugs
             fuer die Verguetung fuer mehrjaehrige Taetigkeit  */
        this.internals.ZRE4VP1 = new BigDecimal(0);

        /**  Feste Tabellenfreibetraege (ohne Vorsorgepauschale) in EURO  */
        this.internals.ZTABFB = new BigDecimal(0);

        /**  Auf einen Jahreslohn hochgerechnetes (this.inputs.VBEZ abzueglich this.internals.FVB) in
             EURO, C (2 Dezimalstellen)  */
        this.internals.ZVBEZ = new BigDecimal(0);

        /**  Zu versteuerndes Einkommen in EURO  */
        this.internals.ZVE = new BigDecimal(0);

        /**  Zwischenfelder zu this.internals.X fuer die Berechnung der Steuer nach § 39b
             Abs. 2 Satz 8 EStG in EURO. */
        this.internals.ZX = new BigDecimal(0);
        this.internals.ZZX = new BigDecimal(0);
        this.internals.HOCH = new BigDecimal(0);
        this.internals.VERGL = new BigDecimal(0);
    
    
  }
  

    /**  PROGRAMMABLAUFPLAN 2006  */

    main() {
        this.MRE4LZZ();
        this.internals.KENNZ = 0;
        this.internals.RE4LZZ = this.inputs.RE4.subtract(this.internals.FVB).subtract(this.internals.ALTE).subtract(this.inputs.WFUNDF).add(this.inputs.HINZUR);
        this.internals.RE4LZZV = this.inputs.RE4.subtract(this.internals.FVB).subtract(this.internals.ALTE);
        this.MRE4();
        this.MZTABFB();
        this.MLSTJAHR();
        this.internals.LSTJAHR = this.internals.ST;
        this.internals.JW = this.internals.LSTJAHR.multiply(ZAHL100);
        this.UPANTEIL();
        this.outputs.LSTLZZ = this.internals.ANTEIL1;

        if (this.inputs.ZKF.compareTo(ZAHL0) == 1) {
        
            this.internals.ZTABFB = this.internals.ZTABFB.add(this.internals.KFB);
            this.MLSTJAHR();
            this.internals.JBMG = this.internals.ST;
        
        }else {
            this.internals.JBMG = this.internals.LSTJAHR;
        
        }

        this.MSOLZ();
        this.MSONST();
        this.MVMT();
    }




    /**  Freibetraege fuer Versorgungsbezuege, Altersentlastungsbetrag (§39b Abs. 2 Satz 2 EStG) 
         PAP Seite 10  */

    MRE4LZZ() {
        if (this.inputs.VBEZ.compareTo(ZAHL0) == 0) {      
        
            this.internals.FVBZ = ZAHL0;
            this.internals.FVB = ZAHL0;
        
        }else {
            if (this.inputs.VJAHR < 2006) {
            
                this.internals.J = 1;
            
            }else {
                if (this.inputs.VJAHR < 2040) {
                
                    this.internals.J = this.inputs.VJAHR - 2004;
                
                }else {
                    this.internals.J = 36;
                
                }
            
            }

            if (this.inputs.LZZ == 1) {
            
                if (((this.inputs.STERBE.add(this.inputs.VKAPA)).compareTo(ZAHL0)) == 1) {
                
                    this.internals.VBEZB = (this.inputs.VBEZM.multiply(BigDecimal.valueOf(this.inputs.ZMVB))).add(this.inputs.VBEZS);  
                    this.internals.HFVB = BigDecimal.valueOf(TAB2[this.internals.J] * 100);
                    this.internals.FVBZ = BigDecimal.valueOf(TAB3[this.internals.J]);
                
                }else {
                     this.internals.VBEZB = (this.inputs.VBEZM.multiply(BigDecimal.valueOf(this.inputs.ZMVB))).add(this.inputs.VBEZS);  
                     this.internals.HFVB = BigDecimal.valueOf(TAB2[this.internals.J] / 12 * this.inputs.ZMVB * 100);
                     this.internals.FVBZ = (BigDecimal.valueOf(TAB3[this.internals.J] / 12 * this.inputs.ZMVB)).setScale(0, BigDecimal.ROUND_UP);
                
                }
            
            }else {
                this.internals.VBEZB = ((this.inputs.VBEZM.multiply(ZAHL12)).add(this.inputs.VBEZS)).setScale(2, BigDecimal.ROUND_DOWN);
                this.internals.HFVB = BigDecimal.valueOf(TAB2[this.internals.J] * 100);
                this.internals.FVBZ = BigDecimal.valueOf(TAB3[this.internals.J]);
            
            }

            this.internals.FVB = (this.internals.VBEZB.multiply(BigDecimal.valueOf(TAB1[this.internals.J]))).setScale(0, BigDecimal.ROUND_UP);

            if (this.internals.FVB.compareTo(this.internals.HFVB) == 1) {
            
                this.internals.FVB = this.internals.HFVB;
            
            }else {
            
            }

            this.internals.JW = this.internals.FVB;
            this.UPANTEIL();
            this.internals.FVB = this.internals.ANTEIL2;
        
        }

        if (this.inputs.ALTER1 == 0) {
        
            this.internals.ALTE = ZAHL0;
        
        }else {
            if (this.inputs.AJAHR < 2006) {
            
                this.internals.K = 1;
            
            }else {
                if (this.inputs.AJAHR < 2040) {
                
                    this.internals.K = this.inputs.AJAHR - 2004;
                
                }else {
                    this.internals.K = 36;
                
                }
            
            }

            this.internals.BMG = this.inputs.RE4.subtract(this.inputs.VBEZ);
            this.internals.ALTE = (this.internals.BMG.multiply(BigDecimal.valueOf(TAB4[this.internals.K]))).setScale(0, BigDecimal.ROUND_UP);
            this.internals.JW = BigDecimal.valueOf(TAB5[this.internals.K] * 100);
            this.UPANTEIL();

            if (this.internals.ALTE.compareTo(this.internals.ANTEIL2) == 1) {
            
                this.internals.ALTE = this.internals.ANTEIL2;
            
            }else {
            
            }
        
        }
    }


    /**  Massgeblicher Arbeitslohn fuer die Jahreslohnsteuer 
         PAP Seite 12  */

    MRE4() {

        if (this.inputs.LZZ == 1) {
        
            this.internals.ZRE4 = this.internals.RE4LZZ.divide(ZAHL100, 2, BigDecimal.ROUND_DOWN);
            this.internals.ZRE4VP = this.internals.RE4LZZV.divide(ZAHL100, 2, BigDecimal.ROUND_DOWN);
            this.internals.ZVBEZ = (this.inputs.VBEZ.subtract(this.internals.FVB)).divide(ZAHL100, 2, BigDecimal.ROUND_DOWN);
        

        }else {
            if (this.inputs.LZZ == 2) {
            
                this.internals.ZRE4 = ((this.internals.RE4LZZ.add(BigDecimal.valueOf(0.67))).multiply(BigDecimal.valueOf(0.12))).setScale(2, BigDecimal.ROUND_DOWN);
                this.internals.ZRE4VP = ((this.internals.RE4LZZV.add(BigDecimal.valueOf(0.67))).multiply(BigDecimal.valueOf(0.12))).setScale(2, BigDecimal.ROUND_DOWN);
                this.internals.ZVBEZ = ((this.inputs.VBEZ.subtract(this.internals.FVB).add(BigDecimal.valueOf(0.67))).multiply(BigDecimal.valueOf(0.12))).setScale(2, BigDecimal.ROUND_DOWN);
            

            }else {
                if (this.inputs.LZZ == 3) {
                
                    this.internals.ZRE4 = ((this.internals.RE4LZZ.add(BigDecimal.valueOf(0.89))).multiply(BigDecimal.valueOf(3.6/7.0))).setScale(2, BigDecimal.ROUND_DOWN);
                    this.internals.ZRE4VP = ((this.internals.RE4LZZV.add(BigDecimal.valueOf(0.89))).multiply(BigDecimal.valueOf(3.6/7.0))).setScale(2, BigDecimal.ROUND_DOWN);
                    this.internals.ZVBEZ = ((this.inputs.VBEZ.subtract(this.internals.FVB).add(BigDecimal.valueOf(0.89))).multiply(BigDecimal.valueOf(3.6/7.0))).setScale(2, BigDecimal.ROUND_DOWN);
                
                }else {
                    this.internals.ZRE4 = ((this.internals.RE4LZZ.add(BigDecimal.valueOf(0.56))).multiply(BigDecimal.valueOf(3.6))).setScale(2, BigDecimal.ROUND_DOWN);
                    this.internals.ZRE4VP = ((this.internals.RE4LZZV.add(BigDecimal.valueOf(0.56))).multiply(BigDecimal.valueOf(3.6))).setScale(2, BigDecimal.ROUND_DOWN);
                    this.internals.ZVBEZ = ((this.inputs.VBEZ.subtract(this.internals.FVB).add(BigDecimal.valueOf(0.56))).multiply(BigDecimal.valueOf(3.6))).setScale(2, BigDecimal.ROUND_DOWN);
                
                }
            
            }
        
        }

        if (this.internals.ZRE4.compareTo(ZAHL0) == -1) {
        
            this.internals.ZRE4 = ZAHL0;
        
        }else {
        
        }

        if (this.internals.ZVBEZ.compareTo(ZAHL0) == -1) {
        
            this.internals.ZVBEZ = ZAHL0;
        
        }else {
        
        }

    }


    /**  Ermittlung der festen Tabellenfreibetraege (ohne Vorsorgepauschale)
         PAP Seite 13  */

    MZTABFB() {

        this.internals.ANP = ZAHL0;

        if (this.internals.ZVBEZ.compareTo(ZAHL0) == 1) {
        
            if (this.internals.ZVBEZ.compareTo(this.internals.FVBZ) == -1) {
            
                /**  Fehler im PAP? double -> int, Nachkommastellen abschneiden  */
                this.internals.FVBZ = this.internals.ZVBEZ.setScale(0, BigDecimal.ROUND_DOWN);
            
            }else {
            
            }
        
        }else {
        
        }

        if (this.inputs.STKL < 6) {
        
            if (this.internals.ZVBEZ.compareTo(ZAHL0) == 1) {
            
                if ((this.internals.ZVBEZ.subtract(this.internals.FVBZ)).compareTo(BigDecimal.valueOf(102)) == -1) {
                
                   /**  Fehler im PAP? double -> int, Nachkommastellen abschneiden  */
                   this.internals.ANP = (this.internals.ZVBEZ.subtract(this.internals.FVBZ)).setScale(0, BigDecimal.ROUND_DOWN);
                
                }else {
                    this.internals.ANP = BigDecimal.valueOf(102);
                
                }
            
            }else {
            
            }
        
        }else {
        
        }

        if (this.inputs.STKL < 6) {
        
            if (this.internals.ZRE4.compareTo(this.internals.ZVBEZ) == 1) {
            
                if ((this.internals.ZRE4.subtract(this.internals.ZVBEZ)).compareTo(BigDecimal.valueOf(920)) == -1) {
                
                    /**  Fehler im PAP? double -> int, Nachkommastellen abschneiden  */
                    this.internals.ANP = (this.internals.ANP.add(this.internals.ZRE4).subtract(this.internals.ZVBEZ)).setScale(0, BigDecimal.ROUND_DOWN);
                
                }else {
                    this.internals.ANP = this.internals.ANP.add(BigDecimal.valueOf(920));
                
                }
            
            }else {
            
            }
        
        }else {
        
        }

        this.internals.KZTAB = 1;

        if (this.inputs.STKL == 1) {
        /**  this.inputs.ZKF ist double und this.internals.KFB ist integer. Nachkommastellen abschneiden! 4x!!!  */
        
            this.internals.SAP = BigDecimal.valueOf(36);
            this.internals.KFB = (this.inputs.ZKF.multiply(BigDecimal.valueOf(5808))).setScale(0, BigDecimal.ROUND_DOWN);
        
        }else {
            if (this.inputs.STKL == 2) {
            
                this.internals.EFA = BigDecimal.valueOf(1308);
                this.internals.SAP = BigDecimal.valueOf(36);
                this.internals.KFB = (this.inputs.ZKF.multiply(BigDecimal.valueOf(5808))).setScale(0, BigDecimal.ROUND_DOWN);
            
            }else {
                if (this.inputs.STKL == 3) {
                
                    this.internals.KZTAB = 2;
                    this.internals.SAP = BigDecimal.valueOf(72);
                    this.internals.KFB = (this.inputs.ZKF.multiply(BigDecimal.valueOf(5808))).setScale(0, BigDecimal.ROUND_DOWN);
                
                }else {
                    if (this.inputs.STKL == 4) {
                    
                        this.internals.SAP = BigDecimal.valueOf(36);
                        this.internals.KFB = (this.inputs.ZKF.multiply(BigDecimal.valueOf(2904))).setScale(0, BigDecimal.ROUND_DOWN);
                    
                    }else {
                        this.internals.KFB = ZAHL0;
                    
                    }
                
                }
            
            }
            
        }
        this.internals.ZTABFB = this.internals.EFA.add(this.internals.ANP).add(this.internals.SAP).add(this.internals.FVBZ);
    }


    /**  Ermittlung Jahreslohnsteuer
         PAP Seite 14  */

    MLSTJAHR() {

        if (this.inputs.STKL < 5) {
        
            this.UPEVP();
        
        }else {
            this.internals.VSP = ZAHL0;
        
        }

        /**  this.internals.ZVE ist in EURO, this.internals.ZRE4 in EURO,Cent  */
        this.internals.ZVE = (this.internals.ZRE4.subtract(this.internals.ZTABFB).subtract(this.internals.VSP)).setScale(0, BigDecimal.ROUND_DOWN);

        if (this.internals.ZVE.compareTo(ZAHL1) == -1) {
        
            this.internals.ZVE = ZAHL0;
            this.internals.X = ZAHL0;
        
        }else {
            this.internals.X = this.internals.ZVE.divide(BigDecimal.valueOf(this.internals.KZTAB), 0, BigDecimal.ROUND_DOWN);
        
        }

        if (this.inputs.STKL < 5) {
        
            this.UPTAB05();
        
        }else {
            this.MST5_6();
        
        }

    }


    /**  Vorsorgepauschale (§39b Abs. 2 Satz 6 Nr 3 EStG) 
         PAP Seite 15  */

    UPEVP() {

        if (this.inputs.KRV == 1) {
        
            this.internals.VSP1 = ZAHL0;
        
        }else {

            if (this.internals.ZRE4VP.compareTo(BigDecimal.valueOf(63000)) == 1) {
            
                this.internals.ZRE4VP = BigDecimal.valueOf(63000);
            
            }else {
            
            }

        this.internals.VSP1 = (this.internals.ZRE4VP.multiply(BigDecimal.valueOf(0.24))).setScale(2, BigDecimal.ROUND_DOWN);
        this.internals.VSP1 = (this.internals.VSP1.multiply(BigDecimal.valueOf(0.0975))).setScale(2, BigDecimal.ROUND_DOWN);

        
        }

        this.internals.VSP2 = this.internals.ZRE4VP.multiply(BigDecimal.valueOf(0.11));
        this.internals.VHB = BigDecimal.valueOf(1500 * this.internals.KZTAB);

        if (this.internals.VSP2.compareTo(this.internals.VHB) == 1) {
        
            this.internals.VSP2 = this.internals.VHB;
        
        }else {
        
        }
        /**  Erst auf 2 nachkommastellen kuerzen, dann aufrunden, sonst 
             wird die Jahreslohnsteuer ggf. um 1 EUR zu hoch angesetzt.
             Hinweis: wieder aufgehoben, da bei this.internals.VSP1 eine Rundung fehlte.  */
        this.internals.VSPN = (this.internals.VSP1.add(this.internals.VSP2)).setScale(0, BigDecimal.ROUND_UP);
        this.MVSP();

        if (this.internals.VSPN.compareTo(this.internals.VSP) == 1) {    
        
            this.internals.VSP = this.internals.VSPN.setScale(2, BigDecimal.ROUND_DOWN);
        
        }else {
        
        }

    }


    /**  Vorsorgepauschale (§39b Abs. 2 Satz 6 Nr 3 EStG) Vergleichsberechnung 
         fuer Guenstigerpruefung
         PAP Seite 16  */

    MVSP() {

        if (this.internals.KENNZ == 1) {
        
           this.internals.VSPO = this.internals.ZRE4VP1.multiply(BigDecimal.valueOf(0.2));
        
        }else {
           this.internals.VSPO = this.internals.ZRE4VP.multiply(BigDecimal.valueOf(0.2));
        
        }

        this.internals.VSPVOR = BigDecimal.valueOf(this.internals.KZTAB * 3068);
        this.internals.VSPMAX1 = BigDecimal.valueOf(this.internals.KZTAB * 1334);
        this.internals.VSPMAX2 = BigDecimal.valueOf(this.internals.KZTAB * 667);
        this.internals.VSPKURZ = BigDecimal.valueOf(this.internals.KZTAB * 1134);

        if (this.inputs.KRV == 1) {
        
            if (this.internals.VSPO.compareTo(this.internals.VSPKURZ) == 1) {
            
                this.internals.VSP = this.internals.VSPKURZ;
            
            }else {
                this.internals.VSP = this.internals.VSPO.setScale(2, BigDecimal.ROUND_UP);
            
            }
        
        }else {
            this.UMVSP();
        
        }

    }


    /**  Vorsorgepauschale
         PAP Seite 17  */

    UMVSP() {

        if (this.internals.KENNZ == 1) {
        
            this.internals.VSPVOR = this.internals.VSPVOR.subtract(this.internals.ZRE4VP1.multiply(BigDecimal.valueOf(0.16)));
        
        }else {
            this.internals.VSPVOR = this.internals.VSPVOR.subtract(this.internals.ZRE4VP.multiply(BigDecimal.valueOf(0.16)));
        
        }

        if (this.internals.VSPVOR.compareTo(ZAHL0) == -1) {
        
            this.internals.VSPVOR = ZAHL0;
        
        }else {
        
        }

        if (this.internals.VSPO.compareTo(this.internals.VSPVOR) == 1) {
        
            this.internals.VSP = this.internals.VSPVOR;
            this.internals.VSPREST = this.internals.VSPO.subtract(this.internals.VSPVOR);

            if (this.internals.VSPREST.compareTo(this.internals.VSPMAX1) == 1) {
            
                this.internals.VSP = this.internals.VSP.add(this.internals.VSPMAX1);
                this.internals.VSPREST = (this.internals.VSPREST.subtract(this.internals.VSPMAX1)).divide(ZAHL2, 2, BigDecimal.ROUND_UP);

                if (this.internals.VSPREST.compareTo(this.internals.VSPMAX2) == 1) {
                
                    this.internals.VSP = (this.internals.VSP.add(this.internals.VSPMAX2)).setScale(0, BigDecimal.ROUND_UP);
                
                }else {
                    this.internals.VSP = (this.internals.VSP.add(this.internals.VSPREST)).setScale(0, BigDecimal.ROUND_UP);
                
                }
            
            }else {
                this.internals.VSP = (this.internals.VSP.add(this.internals.VSPREST)).setScale(0, BigDecimal.ROUND_UP);
            
            }
        
        }else {
            this.internals.VSP = this.internals.VSPO.setScale(0, BigDecimal.ROUND_UP);
        
        }

    }


    /**  Lohnsteuer fuer die Steuerklassen V und VI (§ 39b Abs. 2 Satz 8 EStG)
         PAP Seite 18  */

    MST5_6() {

        this.internals.ZZX = this.internals.X;

        if (this.internals.ZZX.compareTo(BigDecimal.valueOf(25812)) == 1) {
        
            this.internals.ZX = BigDecimal.valueOf(25812);
            this.UP5_6();
            this.internals.ST = (this.internals.ST.add((this.internals.ZZX.subtract(BigDecimal.valueOf(25812))).multiply(BigDecimal.valueOf(0.42)))).setScale(0, BigDecimal.ROUND_DOWN);
        
        }else {
            this.internals.ZX = this.internals.ZZX;
            this.UP5_6();

            if (this.internals.ZZX.compareTo(BigDecimal.valueOf(9144)) == 1) {
            
                this.internals.VERGL = this.internals.ST;
                this.internals.ZX = BigDecimal.valueOf(9144);
                this.UP5_6();
                this.internals.HOCH = (this.internals.ST.add((this.internals.ZZX.subtract(BigDecimal.valueOf(9144))).multiply(BigDecimal.valueOf(0.42)))).setScale(0, BigDecimal.ROUND_DOWN);

                if (this.internals.HOCH.compareTo(this.internals.VERGL) == -1) {
                
                    this.internals.ST = this.internals.HOCH;
                
                }else {
                    this.internals.ST = this.internals.VERGL;
                
                }
            
            }else {
            
            }
        
        }

    }


    /**  Lohnsteuer fuer die Steuerklassen V und VI (§ 39b Abs. 2 Satz 8 EStG)
         PAP Seite 18  */

    UP5_6() {

        this.internals.X = this.internals.ZX.multiply(BigDecimal.valueOf(1.25));
        this.UPTAB05();
        this.internals.ST1 = this.internals.ST;
        this.internals.X = this.internals.ZX.multiply(BigDecimal.valueOf(0.75));
        this.UPTAB05();
        this.internals.ST2 = this.internals.ST;
        this.internals.DIFF = (this.internals.ST1.subtract(this.internals.ST2)).multiply(ZAHL2);
        this.internals.MIST = (this.internals.ZX.multiply(BigDecimal.valueOf(0.15))).setScale(0, BigDecimal.ROUND_DOWN);

        if (this.internals.MIST.compareTo(this.internals.DIFF) == 1) {
        
            this.internals.ST = this.internals.MIST;
        
        }else {
            this.internals.ST = this.internals.DIFF;
        
        }

    }


    /**  Solidaritaetszuschlag
         PAP Seite 19  */

    MSOLZ() {

        this.internals.SOLZFREI = BigDecimal.valueOf(972 * this.internals.KZTAB);

        if (this.internals.JBMG.compareTo(this.internals.SOLZFREI) == 1) {
        
            this.internals.SOLZJ = (this.internals.JBMG.multiply(BigDecimal.valueOf(5.5/100))).setScale(2, BigDecimal.ROUND_DOWN);
            this.internals.SOLZMIN = (this.internals.JBMG.subtract(this.internals.SOLZFREI)).multiply(BigDecimal.valueOf(20.0/100.0));

            if (this.internals.SOLZMIN.compareTo(this.internals.SOLZJ) == -1) {
            
                this.internals.SOLZJ = this.internals.SOLZMIN;
            
            }else {
            
            }

            this.internals.JW = this.internals.SOLZJ.multiply(ZAHL100).setScale(0, BigDecimal.ROUND_DOWN);
            this.UPANTEIL();
            this.outputs.SOLZLZZ = this.internals.ANTEIL1;
        
        }else {
            this.outputs.SOLZLZZ = ZAHL0;
        
        }

        if (this.inputs.R > 0) {
        
            this.internals.JW = this.internals.JBMG.multiply(ZAHL100);
            this.UPANTEIL();
            this.outputs.BK = this.internals.ANTEIL1;
        
        }else {
            this.outputs.BK = ZAHL0;
        
        }

    }



    /**  Anteil von Jahresbetraegen fuer einen this.inputs.LZZ (§ 39b Abs. 2 Satz 10 EStG)
         PAP Seite 20  */

    UPANTEIL() {

        if (this.inputs.LZZ == 1) {
        
            this.internals.ANTEIL1 = this.internals.JW;
            this.internals.ANTEIL2 = this.internals.JW;
        
        }else {

            if (this.inputs.LZZ == 2) {
            
                this.internals.ANTEIL1 = this.internals.JW.divide(ZAHL12, 0, BigDecimal.ROUND_DOWN);
                this.internals.ANTEIL2 = this.internals.JW.divide(ZAHL12, 0, BigDecimal.ROUND_UP);
            
            }else {

                if (this.inputs.LZZ == 3) {
                
                    this.internals.ANTEIL1 = (this.internals.JW.multiply(ZAHL7)).divide(ZAHL360, 0, BigDecimal.ROUND_DOWN);
                    this.internals.ANTEIL2 = (this.internals.JW.multiply(ZAHL7)).divide(ZAHL360, 0, BigDecimal.ROUND_UP);
                
                }else {
                    this.internals.ANTEIL1 = this.internals.JW.divide(ZAHL360, 0, BigDecimal.ROUND_DOWN);
                    this.internals.ANTEIL2 = this.internals.JW.divide(ZAHL360, 0, BigDecimal.ROUND_UP);
                
                }
            
            }
        
        }

    }



    /**  Berechnung sonstiger Bezuege nach § 39b Abs. 3 Saetze 1 bis 7 EStG)
         PAP Seite 21  */

    MSONST() {

        if (this.inputs.SONSTB.compareTo(ZAHL0) == 1) {
        
            this.inputs.LZZ = 1;
            this.inputs.VBEZ = this.inputs.JVBEZ;
            this.inputs.RE4 = this.inputs.JRE4;
            this.MRE4LZZ();
            this.MRE4LZZ2();
            this.MLSTJAHR();
            this.internals.LST1 = this.internals.ST.multiply(ZAHL100);
            this.inputs.VBEZ = this.inputs.JVBEZ.add(this.inputs.VBS);
            this.inputs.RE4 = this.inputs.JRE4.add(this.inputs.SONSTB);
            this.inputs.VBEZS = this.inputs.VBEZS.add(this.inputs.STERBE);
            this.MRE4LZZ();
            this.MRE4LZZ2();
            this.MLSTJAHR();
            this.internals.LST2 = this.internals.ST.multiply(ZAHL100);
            this.outputs.STS = this.internals.LST2.subtract(this.internals.LST1);
            this.outputs.SOLZS = this.outputs.STS.multiply(BigDecimal.valueOf(5.5)).divide(ZAHL100, 0, BigDecimal.ROUND_DOWN);

            if (this.inputs.R > 0) {
            
                this.outputs.BKS = this.outputs.STS;
            
            }else {
                this.outputs.BKS = ZAHL0;
            
            }
        
        }else {
            this.outputs.STS = ZAHL0;
            this.outputs.SOLZS = ZAHL0;
            this.outputs.BKS = ZAHL0;
        
        }

    }



    /**  Berechnung sonstiger Bezuege nach § 39b Abs. 3 Saetze 1 bis 7 EStG)
         PAP Seite 21  */

    MRE4LZZ2() {

        this.internals.RE4LZZ = this.inputs.RE4.subtract(this.internals.FVB).subtract(this.internals.ALTE).subtract(this.inputs.JFREIB).add(this.inputs.JHINZU);
        this.internals.RE4LZZV = this.inputs.RE4.subtract(this.internals.FVB).subtract(this.internals.ALTE);
        this.MRE4();
        this.MZTABFB();

    }



    /**  Berechnung der Verguetung fuer mehrjaehrige Taetigkeit nach § 39b Abs. 3 Satz 9 EStG)
         PAP Seite 22  */

    MVMT() {

        if ((this.inputs.VMT.add(this.inputs.VKAPA)).compareTo(ZAHL0) == 1) {
        
            this.inputs.LZZ = 1;
            this.inputs.VBEZ = this.inputs.JVBEZ.add(this.inputs.VBS);
            this.inputs.RE4 = this.inputs.JRE4.add(this.inputs.SONSTB);
            this.MRE4LZZ();
            this.MRE4LZZ2();
            this.MLSTJAHR();
            this.internals.LST1 = this.internals.ST.multiply(ZAHL100);
            this.inputs.VMT = this.inputs.VMT.add(this.inputs.VKAPA);
            this.inputs.VBEZS = this.inputs.VBEZS.add(this.inputs.VKAPA);
            this.inputs.VBEZ = this.inputs.VBEZ.add(this.inputs.VKAPA);
            this.inputs.RE4 = this.inputs.JRE4.add(this.inputs.SONSTB).add(this.inputs.VMT);
            this.MRE4LZZ();
            this.MRE4LZZ2();
            this.internals.KENNZ = 1;
            this.internals.ZRE4VP1 = this.internals.ZRE4VP;
            this.MLSTJAHR();
            this.internals.LST3 = this.internals.ST.multiply(ZAHL100);
            this.inputs.VBEZ = this.inputs.VBEZ.subtract(this.inputs.VKAPA);
            this.inputs.RE4 = this.inputs.JRE4.add(this.inputs.SONSTB);
            this.MRE4LZZ();

            if ((this.inputs.RE4.subtract(this.inputs.JFREIB).add(this.inputs.JHINZU)).compareTo(ZAHL0) == -1) {
            
                this.inputs.RE4 = this.inputs.RE4.subtract(this.inputs.JFREIB).add(this.inputs.JHINZU);
                this.inputs.JFREIB = ZAHL0;
                this.inputs.JHINZU = ZAHL0;
                this.inputs.RE4 = (this.inputs.RE4.add(this.inputs.VMT)).divide(ZAHL5, 0, BigDecimal.ROUND_DOWN);
                this.MRE4LZZ2();
                this.MLSTJAHR();
                this.internals.LST2 = this.internals.ST.multiply(ZAHL100);
                this.outputs.STV = this.internals.LST2.multiply(ZAHL5);
            
            }else {
                this.inputs.RE4 = this.inputs.RE4.add(this.inputs.VMT.divide(ZAHL5, 0, BigDecimal.ROUND_DOWN));
                this.MRE4LZZ2();
                this.MLSTJAHR();
                this.internals.LST2 = this.internals.ST.multiply(ZAHL100);
                this.outputs.STV = (this.internals.LST2.subtract(this.internals.LST1)).multiply(ZAHL5);
            
            }

            this.internals.LST3 = this.internals.LST3.subtract(this.internals.LST1);

            if (this.internals.LST3.compareTo(this.outputs.STV) == -1) {
            
                this.outputs.STV = this.internals.LST3;
            
            }else {
            
            }

            this.outputs.SOLZV = (this.outputs.STV.multiply(BigDecimal.valueOf(5.5))).divide(ZAHL100, 0, BigDecimal.ROUND_DOWN);

            if (this.inputs.R > 0) {
            
                this.outputs.BKV = this.outputs.STV;
            
            }else {
                this.outputs.BKV = ZAHL0;
            
            }
        
        }else {
            this.outputs.STV = ZAHL0;
            this.outputs.SOLZV = ZAHL0;
            this.outputs.BKV = ZAHL0;
        
        }

    }


    /**  Berechnung der Verguetung fuer mehrjaehrige Taetigkeit nach § 39b Abs. 3 Satz 9 EStG)
         PAP Seite 23  */

    UPTAB05() {

        if (this.internals.X.compareTo(BigDecimal.valueOf(7665)) == -1) {
        
            this.internals.ST = ZAHL0; 
        
        }else {

            if (this.internals.X.compareTo(BigDecimal.valueOf(12740)) == -1) {
            
                this.internals.Y = (this.internals.X.subtract(BigDecimal.valueOf(7664))).divide(BigDecimal.valueOf(10000), 6, BigDecimal.ROUND_DOWN);
                this.internals.RW = this.internals.Y.multiply(BigDecimal.valueOf(883.74));
                this.internals.RW = this.internals.RW.add(BigDecimal.valueOf(1500));
                this.internals.ST = (this.internals.RW.multiply(this.internals.Y)).setScale(0, BigDecimal.ROUND_DOWN);
            
            }else {

            if (this.internals.X.compareTo(BigDecimal.valueOf(52152)) == -1) {
            
                this.internals.Y = (this.internals.X.subtract(BigDecimal.valueOf(12739))).divide(BigDecimal.valueOf(10000), 6, BigDecimal.ROUND_DOWN);
                this.internals.RW = this.internals.Y.multiply(BigDecimal.valueOf(228.74));
                this.internals.RW = this.internals.RW.add(BigDecimal.valueOf(2397));
                this.internals.RW = this.internals.RW.multiply(this.internals.Y);
                this.internals.ST = (this.internals.RW.add(BigDecimal.valueOf(989))).setScale(0, BigDecimal.ROUND_DOWN);
            
            }else {
                this.internals.ST = ((this.internals.X.multiply(BigDecimal.valueOf(0.42))).subtract(BigDecimal.valueOf(7914))).setScale(0, BigDecimal.ROUND_DOWN);
            
            }
            
        }
        
        }

        this.internals.ST = this.internals.ST.multiply(BigDecimal.valueOf(this.internals.KZTAB));

    }

    
}

Lohnsteuer2006Big.TAB1 = TAB1;
Lohnsteuer2006Big.TAB2 = TAB2;
Lohnsteuer2006Big.TAB3 = TAB3;
Lohnsteuer2006Big.TAB4 = TAB4;
Lohnsteuer2006Big.TAB5 = TAB5;
Lohnsteuer2006Big.ZAHL0 = ZAHL0;
Lohnsteuer2006Big.ZAHL1 = ZAHL1;
Lohnsteuer2006Big.ZAHL2 = ZAHL2;
Lohnsteuer2006Big.ZAHL3 = ZAHL3;
Lohnsteuer2006Big.ZAHL4 = ZAHL4;
Lohnsteuer2006Big.ZAHL5 = ZAHL5;
Lohnsteuer2006Big.ZAHL6 = ZAHL6;
Lohnsteuer2006Big.ZAHL7 = ZAHL7;
Lohnsteuer2006Big.ZAHL8 = ZAHL8;
Lohnsteuer2006Big.ZAHL9 = ZAHL9;
Lohnsteuer2006Big.ZAHL10 = ZAHL10;
Lohnsteuer2006Big.ZAHL11 = ZAHL11;
Lohnsteuer2006Big.ZAHL12 = ZAHL12;
Lohnsteuer2006Big.ZAHL100 = ZAHL100;
Lohnsteuer2006Big.ZAHL360 = ZAHL360;


module.exports = Lohnsteuer2006Big;
  