const level = require( 'level' ),
  bmfQuery  = require( 'bmf-steuerrechner-api' ).query;

const calculators = require( '../' ),
  parameters      = require( './parameters' );

const testDB = level( __dirname + '/testDB', {
  keyEncoding:   'json',
  valueEncoding: 'json'
} );



function calculate( year, version, input ) {

  let calculation = new calculators[ year ][ version ].calculator();

  calculation.set( input );

  calculation.main();

  return calculation.get( 'outputs' );
}

function compare( output, bmfOutput ) {

  let pass = true,
    result = {};

  for (let key in output) {
    result[ key ] = output[ key ];
    if ( output[ key ] != bmfOutput[ key ] ) {
      result[ key ] = output[ key ] + ' | ' + bmfOutput[ key ];
      pass          = false;
    }
  }

  return [
    pass,
    result
  ];
}

function save( year, version, input, output ) {
  testDB.put( {
    year:    year,
    version: version,
    input:   input
  }, output );

  return output;
}

function load( year, version, input ) {
  return new Promise( ( resolve, reject ) => {
    testDB.get( {
      year:    year,
      version: version,
      input:   input
    }, ( err, result ) => {
      if ( err ) {
        reject( err );
      } else {
        resolve( result );
      }
    } );
  } );
}


function transformBmfResponse( response ) {
  for (let key in response.ausgaben) {
    response.ausgaben[ key ] = response.ausgaben[ key ].value;
  }
  return response;
}


function test( year, version, input ) {

  return new Promise( ( resolve, reject ) => {
    load( year, version, input )
      .catch( () => {
        return bmfQuery( year, version, input )
          .then( transformBmfResponse )
          .then( result => save( year, version, input, result ) );
      } )
      .then( result => {

        let calculation = calculate( year, version, input ),
          comparison    = compare( calculation, result.ausgaben );

        if ( !comparison[ 0 ] ) {
          reject( {
            year:    year,
            version: version,
            error:   comparison[ 1 ]
          } );
        // console.error( '-- difference: ', year, version, comparison[ 1 ] );
        } else {
          resolve( {
            year:    year,
            version: version
          } );
        }
      } )
      .catch( error => reject( {
        year:    year,
        version: version,
        error:   error
      } ) /*console.error( '---------- error', error, year, version, input )*/ );
  } );
}


let count = 1;

if ( process.argv && process.argv[ 2 ] ) {
  count = process.argv[ 2 ];
}

for (let i = 0; i < count; i++) {

  let testData = parameters.randomized(),
    tests      = [],
    iteration  = i;


  for (let year in calculators) {
    for (let version in calculators[ year ]) {
      tests.push( test( year, version, testData ) );
    }
  }

  Promise
    .all( tests )
    .then( results => console.log( 'run ' + (iteration + 1) + ' of ' + count, testData, results ),
      errors => console.error( 'error: run ' + (iteration + 1) + ' of ' + count, testData, errors ) );
}
